This function calculates the variance-covariance matrix using the local mean
estimator.
localmean_cov(zmat, weight_1st)
Arguments
- zmat
Matrix of weighted response values or weighted residual values
for the sample points.
- weight_1st
List from the local mean weight function containing two
elements: a matrix named ij composed of the index values of neighboring
points and a vector named gwt composed of weights.
Value
The local mean estimator of the variance-covariance matrix.