R/localmean_weight.R
localmean_weight.RdThis function calculates the index values of neighboring points and associated weights required by the local mean variance estimator.
localmean_weight(x, y, prb, nbh = 4)If ginv fails to return valid output, a NULL object. Otherwise, a
list containing two elements: a matrix named ij composed of the
index values of neighboring points and a vector named gwt
composed of weights.